Description Usage Arguments Details Value References See Also Examples
View source: R/HC_A0_2_Al_Au.R
Returns the epsilon-grid for HC(A0) heterogeneity prior according to Ott et al. (2019).
1 | HC_A0_2_Al_Au(AA0, eps = grid_epsilon)
|
AA0 |
scale parameter of the base HC distribution |
eps |
epsilon for the epsilon grid |
Local epsilon-grid for the HC distribution which consists of two scale parameters AAl and AAu such that
H(HC(AAl), HC(AA0))=eps,
H(HC(AAu), HC(AA0))=eps.
See more details in Ott et al. (2019).
A vector of two scale parameters AAl and AAu, that is, the local epsilon-grid for the HC distribution which consists of two scale parameters AAl and AAu.
Ott, M., Hunanyan, S., Held, L., Roos, M. (2019). The relative latent model complexity adjustment for heterogeneity prior specification in Bayesian meta-analysis. Research Synthesis Methods (under revision).
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 | # Acute Graft rejection (AGR) data analyzed in Friede et al. (2017),
# Sect. 3.2, URL: https://doi.org/10.1002/bimj.201500236
# First study: experimental group: 14 cases out of 61;
# control group: 15 cases out of 20
# Second study: experimental group: 4 cases out of 36;
# control group: 11 cases out of 36
rT<-c(14,4)
nT<-c(61,36)
rC<-c(15,11)
nC<-c(20,36)
df = data.frame(y = log((rT*(nC-rC))/(rC*(nT-rT))),
sigma = sqrt(1/rT+1/(nT-rT)+1/rC+1/(nC-rC)),
labels = c(1:2))
tau_HC_rlmc025_s <- pri_par_adjust_HC(df=df, rlmc=0.25, tail_prob=0.5)$p_HC
HC_A0_2_Al_Au(AA0=tau_HC_rlmc025_s, eps=0.00354)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.