Description Usage Arguments Details Value References See Also
View source: R/HN_A0_2_Al_Au.R
Returns the epsilon-grid for HN(A0) heterogeneity prior according to Ott et al. (2019).
1 | HN_A0_2_Al_Au(AA0, eps = grid_epsilon)
|
AA0 |
scale parameter of the base HN distribution |
eps |
epsilon for the epsilon grid |
Local epsilon-grid for the HN distribution which consists of two scale parameters AAl and AAu such that
H(HN(AAl), HN(AA0))=eps,
H(HN(AAu), HN(AA0))=eps.
See more details in Ott et al. (2019).
A vector of two scale parameters AAl and AAu, that is, the local epsilon-grid for the HN distribution which consists of two scale parameters AAl and AAu.
Ott, M., Hunanyan, S., Held, L., Roos, M. 2019. The relative latent model complexity adjustment for heterogeneity prior specification in Bayesian meta-analysis. Research Synthesis Methods (under revision).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.